@@ -675,6 +675,8 @@ login_start:
       kDebug(KIO_SFTP_DB) << "Trying to authenticate public key";
       rc = ssh_userauth_autopubkey(mSession, NULL);
       if (rc == SSH_AUTH_ERROR) {
+        kDebug(KIO_SFTP_DB) << "Public key authentication failed: " <<
+               QString::fromUtf8(ssh_get_error(mSession));
         closeConnection();
         error(KIO::ERR_COULD_NOT_LOGIN, i18n("Authentication failed."));
         return;
@@ -683,21 +685,6 @@ login_start:
       }
     }
 
-    // Try to authenticate with keyboard interactive
-    if (method & SSH_AUTH_METHOD_INTERACTIVE) {
-      kDebug(KIO_SFTP_DB) << "Trying to authenticate with keyboard interactive";
-      AuthInfo info2 (info);
-      rc = authenticateKeyboardInteractive(info2);
-      if (rc == SSH_AUTH_ERROR) {
-        closeConnection();
-        error(KIO::ERR_COULD_NOT_LOGIN, i18n("Authentication failed."));
-        return;
-      } else if (rc == SSH_AUTH_SUCCESS) {
-        info = info2;
-        break;
-      }
-    }
-
     if (!firstTime || mPassword.isEmpty()) {
 
       info.keepPassword = true; // make the "keep Password" check box visible to the user.
@@ -728,6 +715,26 @@ login_start:
         closeConnection();
         goto login_start;
       }
+
+      mUsername = info.username;
+      mPassword = info.password;
+    }
+
+    // Try to authenticate with keyboard interactive
+    if (method & SSH_AUTH_METHOD_INTERACTIVE) {
+      kDebug(KIO_SFTP_DB) << "Trying to authenticate with keyboard interactive";
+      AuthInfo info2 (info);
+      rc = authenticateKeyboardInteractive(info2);
+      if (rc == SSH_AUTH_ERROR) {
+        kDebug(KIO_SFTP_DB) << "Keyboard interactive authentication failed: " <<
+               QString::fromUtf8(ssh_get_error(mSession));
+        closeConnection();
+        error(KIO::ERR_COULD_NOT_LOGIN, i18n("Authentication failed."));
+        return;
+      } else if (rc == SSH_AUTH_SUCCESS) {
+        info = info2;
+        break;
+      }
     }
 
     // Try to authenticate with password
@@ -735,6 +742,8 @@ login_start:
       kDebug(KIO_SFTP_DB) << "Trying to authenticate with password";
       rc = ssh_userauth_password(mSession, info.username.toUtf8().constData(), info.password.toUtf8().constData());
       if (rc == SSH_AUTH_ERROR) {
+        kDebug(KIO_SFTP_DB) << "Password authentication failed: " <<
+               QString::fromUtf8(ssh_get_error(mSession));
         closeConnection();
         error(KIO::ERR_COULD_NOT_LOGIN, i18n("Authentication failed."));
         return;
@@ -1855,5 +1864,9 @@ bool sftpProtocol::sftpConnect()
         finished();
         return false;
     }
+    if (!mConnected) {
+        return false;
+    }
+
     return true;
 }
