@@ -1,5 +1,5 @@
 /* This file is part of the KDE Project
-   Copyright (c) 2007-2010 Sebastian Trueg <trueg@kde.org>
+   Copyright (c) 2007-2011 Sebastian Trueg <trueg@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -37,6 +37,8 @@ namespace Soprano {
 class KInotify;
 class KUrl;
 class RegExpCache;
+class ActiveFileQueue;
+class QThread;
 
 namespace Nepomuk {
 
@@ -70,8 +72,8 @@ namespace Nepomuk {
         void slotFileMoved( const QString& from, const QString& to );
         void slotFileDeleted( const QString& urlString, bool isDir );
         void slotFilesDeleted( const QStringList& path );
-        void slotFileCreated( const QString& );
-        void slotFileModified( const QString& );
+        void slotFileCreated( const QString& path, bool isDir );
+        void slotFileClosedAfterWrite( const QString& );
         void slotMovedWithoutData( const QString& );
         void connectToKDirWatch();
 #ifdef BUILD_KINOTIFY
@@ -91,6 +93,8 @@ namespace Nepomuk {
          */
         void slotDeviceMounted( const Nepomuk::RemovableMediaCache::Entry* );
 
+        void slotActiveFileQueueTimeout(const KUrl& url);
+
     private:
         /**
          * Adds watches for all mounted removable media.
@@ -104,6 +108,7 @@ namespace Nepomuk {
          */
         bool ignorePath( const QString& path );
 
+        QThread* m_metadataMoverThread;
         MetadataMover* m_metadataMover;
 
 #ifdef BUILD_KINOTIFY
@@ -112,6 +117,9 @@ namespace Nepomuk {
 
         RegExpCache* m_pathExcludeRegExpCache;
         RemovableMediaCache* m_removableMediaCache;
+
+        /// queue used to "compress" constant file modifications like downloads
+        ActiveFileQueue* m_fileModificationQueue;
     };
 }
 
