@@ -173,10 +173,6 @@ Nepomuk::IndexScheduler::IndexScheduler( QObject* parent )
 
     connect( StrigiServiceConfig::self(), SIGNAL( configChanged() ),
              this, SLOT( slotConfigChanged() ) );
-
-    // start the initial indexing
-    queueAllFoldersForUpdate();
-    callDoIndexing();
 }
 
 
@@ -342,6 +338,8 @@ void Nepomuk::IndexScheduler::doIndexing()
         m_currentMutex.unlock();
 
         setIndexingStarted( false );
+
+        emit indexingDone();
     }
 }
 
